# eric7.WebBrowser.AdBlock.AdBlockUrlInterceptor

Module implementing an URL interceptor base class.

### Global Attributes

None

### Classes

AdBlockUrlInterceptor | Class implementing an URL interceptor for AdBlock.

### Functions

None

## AdBlockUrlInterceptor

Class implementing an URL interceptor for AdBlock.

### Derived from

UrlInterceptor

### Class Attributes

None

### Class Methods

None

### Methods

AdBlockUrlInterceptor | Constructor
interceptRequest | Public method to intercept a request.

### Static Methods

None

#### AdBlockUrlInterceptor (Constructor)

AdBlockUrlInterceptor(manager, parent=None)

Constructor

manager (AdBlockManager)
  reference to the AdBlock manager
parent (QObject)
  referemce to the parent object

#### AdBlockUrlInterceptor.interceptRequest

interceptRequest(info)

Public method to intercept a request.

info (QWebEngineUrlRequestInfo)
  request info object

Up